# py-aiger-bdd
[![Build Status](https://travis-ci.org/mvcisback/py-aiger-bdd.svg?branch=master)](https://travis-ci.org/mvcisback/py-aiger-bdd)
[![codecov](https://codecov.io/gh/mvcisback/py-aiger-bdd/branch/master/graph/badge.svg)](https://codecov.io/gh/mvcisback/py-aiger-bdd)
[![Updates](https://pyup.io/repos/github/mvcisback/py-aiger-bdd/shield.svg)](https://pyup.io/repos/github/mvcisback/py-aiger-bdd/)

[![PyPI version](https://badge.fury.io/py/py-aiger-bdd.svg)](https://badge.fury.io/py/py-aiger-bdd)
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)
